@@ -20,7 +20,6 @@ from Ui_addtoplaylistdialog import Ui_AddToPlaylistDialog
 from Ui_newplaylistdialog import Ui_NewPlaylistDialog
 from Ui_confirmdeletedialog import Ui_ConfirmDeleteDialog
 from Ui_addcommentdialog import Ui_AddCommentDialog
-from Ui_ratevideodialog import Ui_RateVideoDialog
 from Ui_searchdialog import Ui_searchDialog
 from Ui_switchaccountdialog import Ui_SwitchAccountDialog
 from Ui_manageaccountsdialog import Ui_ManageAccountsDialog
@@ -84,15 +83,12 @@ class AddToPlaylistDialog(QDialog, Ui_AddToPlaylistDialog):
         Adds the videos to the chosen playlist.
         """
         row = self.listWidget.row(item)
-        playlist = self.yt.playlistFeed.entry[row]
+        playlistId = self.yt.playlistFeed.entry[row].playlist_id.text
         try:
             self.toggleBusy(True)
             for video in self.videos:
-                if "playlists" in video.id.text:
-                    videoId = video.comments.feed_link[0].href.split("/")[-2]
-                else:
-                    videoId = video.id.text.split("/")[-1]
-                youtubeservice.YouTubeDataService.addVideoToPlaylist(playlist, videoId)
+                videoId = video.media.video_id.text
+                youtubeservice.YouTubeDataService.addVideoToPlaylist(playlistId, videoId)
             if len(self.videos) == 1:
                 QMaemo5InformationBox.information(self, "\'%s\' has been added to your playlist: \'%s\'" % (video.media.title.text, item.text()))
             else:
@@ -159,17 +155,18 @@ class NewPlaylistDialog(QDialog, Ui_NewPlaylistDialog):
         try:
             self.toggleBusy(True)
             playlist = youtubeservice.YouTubeDataService.newPlaylist(playlistTitle, playlistDescription, private)
+            playlistId = playlist.playlist_id.text
             if self.videos == None:
                 QMaemo5InformationBox.information(self, "Your new playlist: \'%s\' has been created" % playlistTitle)
             else:
                 for video in self.videos:
-                    youtubeservice.YouTubeDataService.addVideoToPlaylist(playlist, video.id.text)
+                    youtubeservice.YouTubeDataService.addVideoToPlaylist(playlistId, video.media.video_id.text)
                 if len(self.videos) == 1:
                     QMaemo5InformationBox.information(self, "\'%s\' has been added to your playlist: \'%s\'" % (self.videos[0].media.title.text, playlistTitle))
                 else:
                     QMaemo5InformationBox.information(self, "Your chosen videos have been added to your playlist: \'%s\'" % playlistTitle)
         except:
-            QMaemo5InformationBox.information(self, "Unable to create new playlist") 
+            QMaemo5InformationBox.information(self, playlist) 
         self.toggleBusy(False)
         self.accept()   
 
@@ -185,9 +182,9 @@ class EditPlaylistDialog(NewPlaylistDialog):
         NewPlaylistDialog.__init__(self, parent)
         self.setWindowTitle("Edit Playlist Metadata")
         self.playlist = playlist
-        self.titleEdit.setText(playlist.title.text)
+        self.titleEdit.setText(self.playlist.title.text)
         try:
-            self.descriptionEdit.setText(playlist.description.text)
+            self.descriptionEdit.setText(self.playlist.description.text)
         except:
             pass
         
@@ -200,7 +197,7 @@ class EditPlaylistDialog(NewPlaylistDialog):
         newPlaylistTitle = unicode(self.titleEdit.text())
         newPlaylistDescription = unicode(self.descriptionEdit.toPlainText())
         private = self.privateCheckBox.isChecked()
-        playlistId = self.playlist.id.text.split("/")[-1]
+        playlistId = self.playlist.playlist_id.text
         try:
             self.toggleBusy(True)
             youtubeservice.YouTubeDataService.updatePlaylist(playlistId, newPlaylistTitle, newPlaylistDescription, private)
@@ -315,7 +312,7 @@ class EditPlaylistVideoDialog(NewPlaylistDialog):
         newVideoTitle = unicode(self.titleEdit.text())
         newVideoDescription = unicode(self.descriptionEdit.toPlainText())
         newPosition = unicode(self.positionButton.valueText())
-        playlistVideoId = self.playlistVideo.id.text.split("/")[-1]      
+        playlistVideoId = self.playlistVideo.media.video_id.text
         try:
             self.toggleBusy(True)
             youtubeservice.YouTubeDataService.updatePlaylistVideo(self.playlistId, playlistVideoId, newVideoTitle, newVideoDescription, newPosition)
@@ -365,7 +362,7 @@ class ConfirmDeleteDialog(QDialog, Ui_ConfirmDeleteDialog):
         """
         self.emit(SIGNAL("deleteConfirmed()"))
 
-class RateVideoDialog(QDialog, Ui_RateVideoDialog):
+class RateVideoDialog(QDialog):
     """
     Dialog enabling the user to add a rating to a video.
     """
@@ -374,30 +371,59 @@ class RateVideoDialog(QDialog, Ui_RateVideoDialog):
         Constructor
         """
         QDialog.__init__(self, parent)
-        self.setupUi(self)
+        self.setWindowTitle("Like/Dislike Video")
         self.videoId = videoId
-        for num in range(5):
-            item = QListWidgetItem()
-            ratingLabel = QLabel()
-            ratingLabel.setAlignment(Qt.AlignCenter)
-            ratingLabel.setPixmap(QPixmap(":/images/ui-images/rating%s.0.png" % unicode(num + 1)))
-            self.ratingListWidget.addItem(item)
-            self.ratingListWidget.setItemWidget(item, ratingLabel)
+        self.likeButton = QPushButton(QIcon(":/images/ui-images/likeicon.png"), "Like", self)
+        self.dislikeButton = QPushButton(QIcon(":/images/ui-images/dislikeicon.png"), "Dislike", self)
+        self.connect(QApplication.desktop(), SIGNAL("resized(int)"), self.orientationChanged)
+        for button in (self.likeButton, self.dislikeButton):
+            self.connect(button, SIGNAL("clicked()"), self.likeOrDislike)
+        self.orientationChanged()
         self.show()
+        
+    def orientationChanged(self):
+        """
+        Re-orders the widgets when the application 
+        is in portrait mode.
+        """
+        screenGeometry = QApplication.desktop().screenGeometry()
+        if screenGeometry.height() > screenGeometry.width():
+            self.resize(480, 170)
+            self.likeButton.setGeometry(QRect(10, 10, 460, 70))
+            self.dislikeButton.setGeometry(QRect(10, 90, 460, 70))
+        else:
+            self.resize(800, 90)
+            self.likeButton.setGeometry(QRect(10, 10, 350, 70))
+            self.dislikeButton.setGeometry(QRect(440, 10, 350, 70))
+            
+    def toggleBusy(self, isBusy = False):
+        """
+        Shows the progress indicator if argument is True, 
+        and hides it otherwise.
+        """
+        self.setAttribute(Qt.WA_Maemo5ShowProgressIndicator, isBusy)
     
-    @pyqtSignature("QListWidgetItem*")
-    def on_ratingListWidget_itemClicked(self, item):
+    def likeOrDislike(self):
         """
-        Adds the chosen rating to the video.
+        Add a 'like' or 'dislike' to the video.
         """
-        rating = self.ratingListWidget.row(item) + 1
+        self.toggleBusy(True)
+        if self.sender() is self.likeButton:
+            value = "like"
+        else:
+            value = "dislike"
         try:
-            youtubeservice.YouTubeDataService.addRating(rating, self.videoId)
-            QMaemo5InformationBox.information(self, "You rated this video \'%s stars\'" % unicode(rating)) 
-            self.accept()
-        except:
-            QMaemo5InformationBox.information(self, "Unable to add rating") 
-
+            ratingAdded = youtubeservice.YouTubeDataService.addLikeOrDislike(value, self.videoId)
+            if ratingAdded == True:
+                QMaemo5InformationBox.information(self, "You %sd this video" % value)
+            else:
+                QMaemo5InformationBox.information(self, ratingAdded)
+        except Exception, e:
+            QMaemo5InformationBox.information(self, "Unable to like/dislike this video")
+            CutetubeLog.logException("Unable to like/dislike video: ")
+        self.toggleBusy()
+        self.accept()
+        
 class AddCommentDialog(QDialog, Ui_AddCommentDialog):
     """
     Dialog enabling the user to add a comment to a video.
@@ -435,8 +461,8 @@ class AddCommentDialog(QDialog, Ui_AddCommentDialog):
         Adds a comment to the video referenced by videoID.
         """
         videoTitle = self.video.media.title.text
-        videoId = self.video.id.text
-        author = self.video.author[0].name.text
+        videoId = self.video.media.video_id.text
+        author = self.video.media.credit.text
         try:
             youtubeservice.YouTubeDataService.addComment(self.commentEdit.toPlainText(), videoId)
             QMaemo5InformationBox.information(self, "Your comment has been added to \'%s\'. It may require %s\'s approval." % (unicode(videoTitle, "utf-8"), unicode(author, "utf-8")))
@@ -534,7 +560,7 @@ class SearchDialog(QDialog, Ui_searchDialog):
         from videoinfowindow import VideoInfoWindow
         try:
             videoId = url.split("=") [1].split("&")[0]
-            video = youtubeservice.YouTubeDataService.getVideoEntry(videoId)
+            video = youtubeservice.YouTubeDataService.getVideoEntry(videoId, apiVersion = 2)
             restriction = youtubeservice.YouTubeDataService.getVideoRestrictions(video)
             if restriction == None:
                 videoInfoWindow = VideoInfoWindow(self, video)
