@@ -54,8 +54,6 @@ class CutetubeWindows(QMainWindow, Ui_CutetubeWindows):
         self.connect(self.actionEditVideo, SIGNAL("triggered()"), self.editVideo)
         self.connect(self.moreButton, SIGNAL("pressed()"), self.changeButtonStyleSheet)
         self.connect(self.moreButton, SIGNAL("released()"), self.changeButtonStyleSheet)
-        self.orientationChanged()
-        self.connect(QApplication.desktop(), SIGNAL("resized(int)"), self.orientationChanged) 
         
     def changeButtonStyleSheet(self):
         """
@@ -68,17 +66,6 @@ class CutetubeWindows(QMainWindow, Ui_CutetubeWindows):
             self.moreButton.setStyleSheet("font-size: 18px; border-radius: 4px; background-color: rgb(120, 120, 120, 150)")
         else:
             self.moreButton.setStyleSheet("font-size: 18px; border-radius: 4px; background-color: rgb(0, 0, 0, 100)")
-        
-    def orientationChanged(self):
-        """
-        Sets the position of the 'more' button according to 
-        the screen orientation.
-        """
-        screenGeometry = QApplication.desktop().screenGeometry()
-        if screenGeometry.height() > screenGeometry.width():
-            self.moreButton.setGeometry(QRect(402, 670, 85, 80))
-        else:
-            self.moreButton.setGeometry(QRect(722, 352, 85, 80))
 
     def filterList(self, event):
         """
@@ -141,11 +128,14 @@ class CutetubeWindows(QMainWindow, Ui_CutetubeWindows):
     def addToFavourites(self):
         row = self.listWidget.currentRow()
         video = self.yt.videoList[row]
+        videoId = video.media.video_id.text
         try:
-            youtubeservice.YouTubeDataService.addVideoToFavourites(video)
-            QMaemo5InformationBox.information(self, "\'%s\' has been added to your favourites" % unicode(video.media.title.text, "utf-8"))
+            addedToFavourites = youtubeservice.YouTubeDataService.addVideoToFavourites(videoId)
+            if addedToFavourites == True:
+                QMaemo5InformationBox.information(self, "\'%s\' has been added to your favourites" % unicode(video.title.text, "utf-8"))
+            else:
+                QMaemo5InformationBox.information(self, addedToFavourites)
         except:
-            pass
             QMaemo5InformationBox.information(self, "Unable to add video to your favourites")
         self.listWidget.setCurrentRow(-1)
 
@@ -186,7 +176,7 @@ class CutetubeWindows(QMainWindow, Ui_CutetubeWindows):
         """
         Retrieves further results.
         """
-        if self.yt.isFinished() and self.yt.results < self.yt.totalResults and scrollBarPos > (self.yt.results - 20) * 79:
+        if self.yt.isFinished() and self.yt.moreResults and scrollBarPos > (self.yt.results - 15) * 79:
             self.loadData()
 
     def reloadData(self):
@@ -204,10 +194,10 @@ class CutetubeWindows(QMainWindow, Ui_CutetubeWindows):
         Appends a video item to the listWidget.
         """
         size = QSize()
-        size.setHeight(79)
-        item = QListWidgetItem()
+        size.setHeight(94)
+        item = QListWidgetItem(self.listWidget)
         item.setSizeHint(size)
-        itemWidget = customwidgets.VideoItemWidget(videoData)
+        itemWidget = customwidgets.VideoItemWidget(self.listWidget, videoData)
         if self.actionPencil.isChecked():
             itemWidget.showCheckBox()
             item.setFlags(Qt.ItemIsEnabled)
@@ -273,8 +263,11 @@ class CutetubeWindows(QMainWindow, Ui_CutetubeWindows):
         Adds a subscription to the user's account.
         """
         try:
-            youtubeservice.YouTubeDataService.addSubscription(self.username)
-            QMaemo5InformationBox.information(self, "You have subscribed to \'%s\'!" % unicode(self.username, "utf-8"))
+            subscribed = youtubeservice.YouTubeDataService.addSubscription(self.username)
+            if subscribed == True:
+                QMaemo5InformationBox.information(self, "You have subscribed to \'%s\'!" % unicode(self.username, "utf-8"))
+            else:
+                QMaemo5InformationBox.information(self, subscribed)
         except:
             QMaemo5InformationBox.information(self, "Unable to add subscription")
         
@@ -398,8 +391,8 @@ class CutetubeWindows(QMainWindow, Ui_CutetubeWindows):
         try:
             self.toggleBusy(True)
             for row in self.pencilList:
-                video = self.yt.videoList[row]
-                youtubeservice.YouTubeDataService.addVideoToFavourites(video)
+                videoId = self.yt.videoList[row].media.video_id.text
+                youtubeservice.YouTubeDataService.addVideoToFavourites(videoId)
             QMaemo5InformationBox.information(self, "Your chosen videos have been added to your favourites")
         except:
             QMaemo5InformationBox.information(self, "Unable to add videos to your favourites")
@@ -507,10 +500,10 @@ class SearchResultsWindow(CutetubeWindows):
         self.show() 
         searchTerms = self.searchString.replace(" ", "+")
         if username == None:
-            self.videoFeed = "http://gdata.youtube.com/feeds/api/videos?vq=%s&racy=include&orderby=%s" % (searchTerms, searchOrder)
+            self.videoFeed = "http://gdata.youtube.com/feeds/api/videos?q=%s&safeSearch=none&orderby=%s" % (searchTerms, searchOrder)
             self.actionSearch.setVisible(True)
         else:
-            self.videoFeed = "http://gdata.youtube.com/feeds/api/videos?author=%s&vq=%s&racy=include&orderby=%s" % (username, searchTerms, searchOrder)
+            self.videoFeed = "http://gdata.youtube.com/feeds/api/videos?author=%s&q=%s&safeSearch=none&orderby=%s" % (username, searchTerms, searchOrder)
         self.yt = youtubeservice.YouTubeVideoFeed(self, self.videoFeed)
         self.connect(self.yt, SIGNAL("dataLoaded(PyQt_PyObject)"), self.addVideo)
         self.connect(self.yt, SIGNAL("thumbnailLoaded(PyQt_PyObject)"), self.addVideoThumbnail)
@@ -524,10 +517,10 @@ class SearchResultsWindow(CutetubeWindows):
         the user of search results.
         """
         size = QSize()
-        size.setHeight(79)
+        size.setHeight(94)
         item = QListWidgetItem()
         item.setSizeHint(size)
-        itemWidget = customwidgets.VideoItemWidget(videoData)
+        itemWidget = customwidgets.VideoItemWidget(self.listWidget, videoData)
         if self.actionPencil.isChecked():
             itemWidget.showCheckBox()
             item.setFlags(Qt.ItemIsEnabled)
@@ -642,7 +635,9 @@ class RelatedVideosWindow(CutetubeWindows):
         self.video = video
         self.pencilList = []
         self.show()
-        self.videoFeed = video.link[4].href
+        for link in video.link:
+            if link.rel.split("#")[-1] == "video.related":
+                self.videoFeed = link.href
         self.yt = youtubeservice.YouTubeVideoFeed(self, self.videoFeed)
         self.connect(self.yt, SIGNAL("dataLoaded(PyQt_PyObject)"), self.addVideo)
         self.connect(self.yt, SIGNAL("thumbnailLoaded(PyQt_PyObject)"), self.addVideoThumbnail)
@@ -650,16 +645,6 @@ class RelatedVideosWindow(CutetubeWindows):
         self.connect(self.listWidget.verticalScrollBar(), SIGNAL("valueChanged(int)"), self.getMoreResults)
         self.loadData()
 
-    def loadData(self):
-        try:
-            self.yt.start()
-            QMaemo5InformationBox.information(self, "Showing related videos for \'%s\'" % unicode(self.video.media.title.text, "utf-8"))
-        except:
-            try:
-                QMaemo5InformationBox.information(self, "Unable to connect to YouTube, please try again")
-            except:
-                pass
-
 class FavouritesWindow(CutetubeWindows):
     """
     Displays the user's favourite videos.
@@ -688,10 +673,14 @@ class FavouritesWindow(CutetubeWindows):
     def removeFromFavourites(self):
         row = self.listWidget.currentRow()
         video = self.yt.videoList[row]
+        videoId = video.media.video_id.text
         try:
-            youtubeservice.YouTubeDataService.removeVideoFromFavourites(video.id.text) 
-            self.reloadData()
-            QMaemo5InformationBox.information(self, "\'%s\' has been removed from your favourites" % unicode(video.media.title.text, "utf-8"))
+            removedFromFavourites = youtubeservice.YouTubeDataService.removeVideoFromFavourites(videoId)
+            if removedFromFavourites == True:
+                self.reloadData()
+                QMaemo5InformationBox.information(self, "\'%s\' has been removed from your favourites" % unicode(video.media.title.text, "utf-8"))
+            else:
+                QMaemo5InformationBox.information(self, removedFromFavourites)
         except:
             QMaemo5InformationBox.information(self, "Unable to remove video from your favourites")
         self.listWidget.setCurrentRow(-1)
@@ -753,10 +742,14 @@ class PlaylistsWindow(CutetubeWindows):
     def deletePlaylist(self):
         row = self.listWidget.currentRow()
         playlist = self.yt.playlistFeed.entry[row]
+        playlistId = playlist.playlist_id.text
         try:
-            youtubeservice.YouTubeDataService.deletePlaylist(playlist.id.text)
-            self.reloadData()
-            QMaemo5InformationBox.information(self, "Your playlist: \'%s\' has been deleted" % unicode(playlist.title.text, "utf-8"))
+            playlistDeleted = youtubeservice.YouTubeDataService.deletePlaylist(playlistId)
+            if playlistDeleted == True:
+                self.listWidget.setRowHidden(row, True)
+                QMaemo5InformationBox.information(self, "Your playlist: \'%s\' has been deleted" % unicode(playlist.title.text, "utf-8"))
+            else:
+                QMaemo5InformationBox.information(self, playlistDeleted)
         except:
             QMaemo5InformationBox.information(self, "Unable to delete your playlist")
         self.listWidget.setCurrentRow(-1)
@@ -768,7 +761,7 @@ class PlaylistsWindow(CutetubeWindows):
         """
         row = self.listWidget.row(item)
         playlistName = self.yt.playlistFeed.entry[row].title.text
-        playlistId = self.yt.playlistFeed.entry[row].id.text
+        playlistId = self.yt.playlistFeed.entry[row].playlist_id.text
         playlistVideosWindow = PlaylistVideosWindow(self, playlistName, playlistId)
         self.connect(playlistVideosWindow,  SIGNAL("queueChanged(int)"),  self.queueChanged)
         self.connect(playlistVideosWindow,  SIGNAL("downloadsChanged(int)"),  self.downloadsChanged)
@@ -811,6 +804,7 @@ class PlaylistVideosWindow(CutetubeWindows):
         """
         CutetubeWindows.__init__(self, parent)
         self.playlistName = playlistName
+        self.playlistId = playlistId
         self.setWindowTitle(self.playlistName)
         self.actionPlayPlaylist.setVisible(True)
         self.actionSearch.setVisible(True)
@@ -824,7 +818,7 @@ class PlaylistVideosWindow(CutetubeWindows):
         self.connect(self.actionRemoveFromPlaylist, SIGNAL("triggered()"), self.removeFromPlaylist)
         self.pencilList = []
         self.show()
-        self.videoFeed = "http://gdata.youtube.com/feeds/api/playlists/%s" % playlistId.split("/")[-1]
+        self.videoFeed = "http://gdata.youtube.com/feeds/api/playlists/%s" % playlistId
         self.yt = youtubeservice.YouTubeVideoFeed(self, self.videoFeed)
         self.connect(self.yt, SIGNAL("dataLoaded(PyQt_PyObject)"), self.addVideo)
         self.connect(self.yt, SIGNAL("thumbnailLoaded(PyQt_PyObject)"), self.addVideoThumbnail)
@@ -834,24 +828,13 @@ class PlaylistVideosWindow(CutetubeWindows):
 
     def editVideo(self):
         row = self.listWidget.currentRow()
-        playlistId = self.yt.ytVideoFeed.id.text
         playlistVideo = self.yt.videoList[row]
         position = row + 1
         count = len(self.yt.videoList)
-        editPlaylistVideoDialog = cutetubedialogs.EditPlaylistVideoDialog(self, playlistId, playlistVideo, position, count)
+        editPlaylistVideoDialog = cutetubedialogs.EditPlaylistVideoDialog(self, self.playlistId, playlistVideo, position, count)
         self.listWidget.setCurrentRow(-1)
         self.connect(editPlaylistVideoDialog, SIGNAL("accepted()"), self.reloadData)
 
-    def addToFavourites(self):
-        row = self.listWidget.currentRow()
-        video = self.yt.videoList[row]
-        try:
-            youtubeservice.YouTubeDataService.addVideoToFavourites(video)
-            QMaemo5InformationBox.information(self, "\'%s\' has been added to your favourites" % unicode(video.title.text, "utf-8"))
-        except:
-            QMaemo5InformationBox.information(self, "Unable to add video to your favourites")
-        self.listWidget.setCurrentRow(-1)
-
     def addToPlaylist(self):
         row = self.listWidget.currentRow()
         video = self.yt.videoList[row]
@@ -861,8 +844,17 @@ class PlaylistVideosWindow(CutetubeWindows):
     def removeFromPlaylist(self):
         row = self.listWidget.currentRow()
         video = self.yt.videoList[row]
-        videoId = video.id.text
-        youtubeservice.YouTubeDataService.removeVideoFromPlaylist(videoId)
+        videoId = self.yt.videoList[row].id.text.split(":")[-1]
+        try:
+            removedFromPlaylist = youtubeservice.YouTubeDataService.removeVideoFromPlaylist(self.playlistId, videoId)
+            if removedFromPlaylist == True:
+                self.reloadData()
+                QMaemo5InformationBox.information(self, "\'%s\' has been removed from your playlist" % unicode(video.media.title.text, "utf-8"))
+            else:
+                QMaemo5InformationBox.information(self, removedFromPlaylist)
+        except:
+            QMaemo5InformationBox.information(self, "Unable to remove video from your playlist")
+        self.listWidget.setCurrentRow(-1)
 
     @pyqtSignature("QListWidgetItem*")
     def on_listWidget_itemClicked(self, item):
@@ -888,11 +880,10 @@ class PlaylistVideosWindow(CutetubeWindows):
                     self.actionPencilFavourites.setVisible(False)           
         else:
             row = self.listWidget.currentRow()
-            playlistId = self.yt.ytVideoFeed.id.text
             playlistVideo = self.yt.videoList[row]
             position = row + 1
             count = len(self.yt.videoList)
-            videoInfoWindow = VideoInfoWindow(self, playlistVideo, playlistId, position, count)
+            videoInfoWindow = VideoInfoWindow(self, playlistVideo, self.playlistId, position, count)
             self.connect(videoInfoWindow, SIGNAL("queueChanged(int)"), self.queueChanged)
             self.connect(videoInfoWindow, SIGNAL("downloadsChanged(int)"), self.downloadsChanged)
             self.listWidget.setCurrentRow(-1)
@@ -952,10 +943,10 @@ class PlaybackQueueWindow(CutetubeWindows):
         Overrides the method in CutetubeWindows.
         """
         size = QSize()
-        size.setHeight(79)
+        size.setHeight(94)
         item = QListWidgetItem()
         item.setSizeHint(size)
-        itemWidget = customwidgets.VideoItemWidget(videoData)
+        itemWidget = customwidgets.VideoItemWidget(self.listWidget, videoData)
         self.listWidget.addItem(item)
         self.listWidget.setItemWidget(item, itemWidget)
         title = itemWidget.titleLabel.text()
@@ -990,11 +981,14 @@ class PlaybackQueueWindow(CutetubeWindows):
     def addToFavourites(self):
         row = self.listWidget.currentRow()
         video = youtubeservice.YouTubeQueueFeed.playlist[row]
+        videoId = video.media.video_id.text
         try:
-            youtubeservice.YouTubeDataService.addVideoToFavourites(video)
-            QMaemo5InformationBox.information(self, "\'%s\' has been added to your favourites" % unicode(video.media.title.text, "utf-8"))
+            addedToFavourites = youtubeservice.YouTubeDataService.addVideoToFavourites(videoId)
+            if addedToFavourites == True:
+                QMaemo5InformationBox.information(self, "\'%s\' has been added to your favourites" % unicode(video.title.text, "utf-8"))
+            else:
+                QMaemo5InformationBox.information(self, addedToFavourites)
         except:
-            pass
             QMaemo5InformationBox.information(self, "Unable to add video to your favourites")
         self.listWidget.setCurrentRow(-1)
 
@@ -1081,9 +1075,12 @@ class SubscriptionsWindow(CutetubeWindows):
         row = self.listWidget.currentRow()
         subscription = self.yt.subscriptionsFeed.entry[row]
         try:
-            youtubeservice.YouTubeDataService.removeSubscription(subscription.id.text)
-            self.listWidget.setRowHidden(row, True)
-            QMaemo5InformationBox.information(self, "You have unsubscribed to \'%s\'" % unicode(subscription.username.text, "utf-8"))
+            unsubscribed = youtubeservice.YouTubeDataService.removeSubscription(subscription.id.text)
+            if unsubscribed == True:
+                self.listWidget.setRowHidden(row, True)
+                QMaemo5InformationBox.information(self, "You have unsubscribed to \'%s\'" % unicode(subscription.username.text, "utf-8"))
+            else:
+                QMaemo5InformationBox.information(self, unsubscribed) 
         except:
             QMaemo5InformationBox.information(self, "Unable to remove your subscription")    
         self.listWidget.setCurrentRow(-1)
@@ -1262,10 +1259,10 @@ class DownloadsWindow(CutetubeWindows):
 
     def addVideo(self, videoData):
         size = QSize()
-        size.setHeight(79)
+        size.setHeight(94)
         item = QListWidgetItem()
         item.setSizeHint(size)
-        self.itemWidget = customwidgets.VideoDownloadItemWidget(videoData)
+        self.itemWidget = customwidgets.VideoDownloadItemWidget(self.listWidget, videoData)
         self.listWidget.addItem(item)
         self.listWidget.setItemWidget(item, self.itemWidget)
         row = self.listWidget.row(item)
@@ -1417,7 +1414,7 @@ class DownloadsWindow(CutetubeWindows):
 
 class CommentsWindow(CutetubeWindows):
     """
-    Displays the comments feed for the video.
+    Displays the comments feed cutetubewindows.pyfor the video.
     """
     def __init__(self, parent, video):
         """
@@ -1430,7 +1427,8 @@ class CommentsWindow(CutetubeWindows):
         self.actionGoToQueue.setVisible(False)
         self.show()
         self.video = video
-        self.yt = youtubeservice.YouTubeCommentsFeed(self, self.video)
+        videoId = self.video.media.video_id.text
+        self.yt = youtubeservice.YouTubeCommentsFeed(self, videoId)
         self.connect(self.yt, SIGNAL("dataLoaded(PyQt_PyObject)"), self.loadComments)
         self.loadData()
         self.toggleBusy(True)
@@ -1452,15 +1450,12 @@ class CommentsWindow(CutetubeWindows):
         else:
             try:
                 commentsNumber = unicode(len(comments))
-                if "playlists" in self.video.id.text:
-                    videoTitle = self.video.title.text
-                else:
-                    videoTitle = self.video.media.title.text
+                videoTitle = self.video.title.text
                 for comment in comments:
                     item = QListWidgetItem()
                     item.setFlags(Qt.ItemIsEnabled)
                     self.listWidget.addItem(item)
-                    commentWidget = customwidgets.CommentWidget(comment.author[0].name.text, comment.content.text, self.listWidget)
+                    commentWidget = customwidgets.CommentWidget(self.listWidget, comment.author[0].name.text, comment.content.text)
                     size = QSize()
                     size.setHeight(commentWidget.height())
                     item.setSizeHint(size)
