@@ -43,7 +43,7 @@ class VideoInfoWindow(QMainWindow, Ui_VideoInfoWindow):
             self.playlistLength = count
             self.actionEditVideo.setVisible(True)
             self.actionEditVideo.setText("Edit custom metadata")
-        if self.video.author[0].name.text == youtubeservice.YouTubeDataService.currentUser:
+        if self.video.media.credit.text == youtubeservice.YouTubeDataService.currentUser:
             self.actionRateVideo.setVisible(False)
             self.actionUserVideos.setVisible(False)
             self.actionEditVideo.setVisible(True)
@@ -63,11 +63,14 @@ class VideoInfoWindow(QMainWindow, Ui_VideoInfoWindow):
         """
         screenGeometry = QApplication.desktop().screenGeometry()
         if screenGeometry.height() > screenGeometry.width():
-            self.ratingLabel.setGeometry(QRect(260, 10, 180, 45))
-            self.viewsLabel.setGeometry(QRect(260, 55, 50, 30))
-            self.viewsNumberLabel.setGeometry(QRect(315, 55, 180, 25))
-            self.commentsLabel.setGeometry(QRect(260, 85, 50, 40))
-            self.commentNumberLabel.setGeometry(QRect(315, 90, 180, 25))
+            self.likeLabel.setGeometry(QRect(260, 15, 45, 45))
+            self.likeCountLabel.setGeometry(QRect(310, 15, 150, 45))
+            self.dislikeLabel.setGeometry(QRect(260, 65, 45, 45))
+            self.dislikeCountLabel.setGeometry(QRect(310, 65, 150, 45))
+            self.viewsLabel.setGeometry(QRect(260, 120, 50, 30))
+            self.viewsNumberLabel.setGeometry(QRect(315, 120, 180, 25))
+            self.commentsLabel.setGeometry(QRect(260, 162, 50, 40))
+            self.commentNumberLabel.setGeometry(QRect(315, 162, 180, 25))
             self.titleLabel.setGeometry(QRect(10, 205, 460, 70))
             self.descriptionTextBox.setGeometry(QRect(10, 275, 460, 295))
             self.clipboardButton.setGeometry(QRect(10, 580, 70, 70))
@@ -77,9 +80,12 @@ class VideoInfoWindow(QMainWindow, Ui_VideoInfoWindow):
             self.playButton.setGeometry(QRect(245, 660, 225, 70))
         else:
             self.titleLabel.setGeometry(QRect(260, 20, 530, 70))
-            self.viewsLabel.setGeometry(QRect(10, 260, 50, 30))
-            self.ratingLabel.setGeometry(QRect(10, 210, 180, 45))
+            self.likeLabel.setGeometry(QRect(10, 210, 45, 45))
+            self.likeCountLabel.setGeometry(QRect(70, 210, 70, 45))
+            self.dislikeLabel.setGeometry(QRect(125, 210, 45, 45))
+            self.dislikeCountLabel.setGeometry(QRect(185, 210, 70, 45))
             self.commentsLabel.setGeometry(QRect(10, 290, 50, 40))
+            self.viewsLabel.setGeometry(QRect(10, 260, 50, 30))
             self.viewsNumberLabel.setGeometry(QRect(70, 260, 180, 25))
             self.commentNumberLabel.setGeometry(QRect(70, 295, 180, 25))
             self.descriptionTextBox.setGeometry(QRect(260, 90, 530, 227))
@@ -104,10 +110,10 @@ class VideoInfoWindow(QMainWindow, Ui_VideoInfoWindow):
         Loads the title and description into the QTextEdit widgets.
         """
         # Load the title and description. Some videos do not have a description, in which case None is returned.
-        self.actionUserVideos.setText("%s\'s Videos" % unicode(self.video.author[0].name.text, "utf-8"))
+        self.actionUserVideos.setText("%s\'s Videos" % unicode(self.video.media.credit.text, "utf-8"))
         self.titleLabel.setText(unicode(self.video.title.text, "utf-8"))       
         try:
-            if "playlists" in self.video.id.text:
+            if "playlist" in self.video.id.text:
                 self.descriptionTextBox.setText(unicode(self.video.content.text, "utf-8"))
             else:
                 self.descriptionTextBox.setText(unicode(self.video.media.description.text, "utf-8"))
@@ -133,9 +139,11 @@ class VideoInfoWindow(QMainWindow, Ui_VideoInfoWindow):
             self.actionViewComments.setVisible(False)
         # Load video's average rating. Some videos may not have a rating, in which case it is set to '3 stars'.
         try:
-            self.ratingLabel.setPixmap(QPixmap(":/images/ui-images/rating%s.png" % unicode(round(float(self.video.rating.average)))))
+            self.likeCountLabel.setText(self.video.likes_and_dislikes.num_likes)
+            self.dislikeCountLabel.setText(self.video.likes_and_dislikes.num_dislikes)
         except:
-            self.ratingLabel.setPixmap(QPixmap(":/images/ui-images/rating3.0.png"))
+            pass
+        
                 
     def loadThumbnail(self):
         """
@@ -144,7 +152,7 @@ class VideoInfoWindow(QMainWindow, Ui_VideoInfoWindow):
         # Load video duration, converting seconds to MM:SS format.
         self.durationLabel.setText(unicode(time.strftime('%M:%S', time.gmtime(float(self.video.media.duration.seconds)))))
         
-        thumbUrl = self.video.media.thumbnail[3].url
+        thumbUrl = self.video.media.thumbnail[4].url
         thumbnail = youtubeservice.YouTubeDataService.getVideoThumbnail(thumbUrl)
         try:
             self.thumbLabel.setPixmap(thumbnail) 
@@ -245,10 +253,10 @@ class VideoInfoWindow(QMainWindow, Ui_VideoInfoWindow):
     @pyqtSignature("")
     def on_actionRateVideo_triggered(self):
         """
-        Raises a dialog asking the user to select a 
-        rating from 1-5 stars.
+        Raises a dialog enabling the user to 'like' or 'dislike' the video.
         """
-        rateVideoDialog = cutetubedialogs.RateVideoDialog(self, self.video.id.text)
+        videoId = self.video.media.video_id.text
+        rateVideoDialog = cutetubedialogs.RateVideoDialog(self, videoId)
 
     @pyqtSignature("")
     def on_actionAddComment_triggered(self):
@@ -273,7 +281,7 @@ class VideoInfoWindow(QMainWindow, Ui_VideoInfoWindow):
         Creates a ChannelWindow displaying all videos 
         from the uploader of the current video.
         """
-        userName = self.video.author[0].name.text
+        userName = self.video.media.credit.text
         userWindow = cutetubewindows.UserWindow(self, userName)
         self.connect(userWindow, SIGNAL("downloadsChanged(int)"), self.downloadsChanged)
         self.connect(userWindow, SIGNAL("queueChanged(int)"), self.queueChanged)
@@ -288,19 +296,6 @@ class VideoInfoWindow(QMainWindow, Ui_VideoInfoWindow):
         self.connect(relatedVideosWindow, SIGNAL("downloadsChanged(int)"), self.downloadsChanged)
         self.connect(relatedVideosWindow, SIGNAL("queueChanged(int)"), self.queueChanged)
     
-    @pyqtSignature("")
-    def on_actionVideoResponse_triggered(self):
-        """
-        Asks the user to choose an existing video from 
-        their account, or upload a new video chosen via 
-        a file dialog.
-        """
-        fileDialog = QFileDialog(self, ("Choose Video Response"))
-        fileDialog.setFileMode(QFileDialog.ExistingFiles)
-        fileDialog.setReadOnly(True)
-        if fileDialog.exec_():
-            pass
-    
     @pyqtSignature("")
     def on_actionAddToFavourites_triggered(self):
         """
@@ -308,8 +303,12 @@ class VideoInfoWindow(QMainWindow, Ui_VideoInfoWindow):
         displays an information box to confirm.
         """
         try:
-            youtubeservice.YouTubeDataService.addVideoToFavourites(self.video)
-            QMaemo5InformationBox.information(self, "\'%s\' has been added to your favourites" % unicode(self.video.media.title.text, "utf-8"))
+            videoId = self.video.media.video_id.text
+            addedToFavourites = youtubeservice.YouTubeDataService.addVideoToFavourites(videoId)
+            if addedToFavourites == True:
+                QMaemo5InformationBox.information(self, "\'%s\' has been added to your favourites" % unicode(self.video.media.title.text, "utf-8"))
+            else:
+                QMaemo5InformationBox.information(self,  addedToFavourites)
         except:
             QMaemo5InformationBox.information(self,  "Unable to add video to your favourites")
 
@@ -326,7 +325,7 @@ class VideoInfoWindow(QMainWindow, Ui_VideoInfoWindow):
         """
         Raises an EditVideoDialog.
         """
-        if "playlists" in self.video.id.text:
+        if "playlist" in self.video.id.text:
             editVideoDialog = cutetubedialogs.EditPlaylistVideoDialog(self, self.playlistId, self.video, self.playlistPosition, self.playlistLength)
         else:
             editVideoDialog = cutetubedialogs.EditVideoDialog(self, self.video)
