@@ -67,67 +67,105 @@ class YouTubeDataService(object):
         """
         Adds a comment to the video argument's comment feed.
         """
-        videoEntry = YouTubeDataService.ytService.GetYouTubeVideoEntry(uri = videoId)
+        videoEntry = YouTubeDataService.getVideoEntry(videoId)
         YouTubeDataService.ytService.AddComment(unicode(comment), videoEntry) 
 
     @staticmethod
-    def addRating(rating, videoId):
+    def addLikeOrDislike(likeOrDislike, videoId):
         """
         Adds a rating to the video argument.
         """
-        videoEntry = YouTubeDataService.ytService.GetYouTubeVideoEntry(uri = videoId)
-        YouTubeDataService.ytService.AddRating(rating, videoEntry)
+        videoEntry = YouTubeDataService.getVideoEntry(videoId, apiVersion = 2)
+        try:
+            YouTubeDataService.ytService.AddLikeOrDislike(likeOrDislike, videoEntry)
+            result = True
+        except gdata.service.Error, e:
+            result = e.args[0].get("body")
+            CutetubeLog.logException(e)
+        return result
     
     @staticmethod
     def addSubscription(username):
         """
         Adds a subscription to the username argument.
         """
-        YouTubeDataService.ytService.AddSubscriptionToChannel(username)
+        try:
+            YouTubeDataService.ytService.AddSubscriptionToChannel(username)
+            result = True
+        except gdata.service.Error, e:
+            result = e.args[0].get("body")
+            CutetubeLog.logException(e)
+        return result
 
     @staticmethod
     def removeSubscription(subscriptionUri):
         """
         Removes the subscription to the specified channel.
         """
-        YouTubeDataService.ytService.DeleteSubscription(subscriptionUri)
+        try:
+            YouTubeDataService.ytService.DeleteSubscription(subscriptionUri)
+            result = True
+        except gdata.service.Error, e:
+            result = e.args[0].get("body")
+            CutetubeLog.logException(e)
+        return result
 
     @staticmethod
-    def addVideoToFavourites(video):
-        if "playlists" in video.id.text:
-            videoId = video.comments.feed_link[0].href.split("/")[-2]
-            video = YouTubeDataService.ytService.GetYouTubeVideoEntry(video_id = videoId)
-        YouTubeDataService.ytService.AddVideoEntryToFavorites(video)
+    def addVideoToFavourites(videoId):
+        video = YouTubeDataService.getVideoEntry(videoId)
+        try:
+            YouTubeDataService.ytService.AddVideoEntryToFavorites(video)
+            result = True
+        except gdata.service.Error, e:
+            result = e.args[0].get("body")
+            CutetubeLog.logException(e)
+        return result
 
     @staticmethod
-    def removeVideoFromFavourites(videoID):
-        YouTubeDataService.ytService.DeleteVideoEntryFromFavorites(videoID.split("/")[-1])
+    def removeVideoFromFavourites(videoId):
+        try:
+            YouTubeDataService.ytService.DeleteVideoEntryFromFavorites(videoId)
+            result = True
+        except gdata.service.Error, e:
+            result = e.args[0].get("body")
+            CutetubeLog.logException(e)
+        return result
 
     @staticmethod
     def newPlaylist(playlistTitle, playlistDescription, private):
         """
         Creates a new playlist using the title and description arguments.
         """
-        return YouTubeDataService.ytService.AddPlaylist(playlistTitle, playlistDescription, private)
+        try:
+            YouTubeDataService.ytService.AddPlaylist(playlistTitle, playlistDescription, private)
+            result = True
+        except gdata.service.Error, e:
+            result = e.args[0].get("body")
+            CutetubeLog.logException(e)
+        return result
 
 
     @staticmethod
-    def addVideoToPlaylist(playlist, videoId):
+    def addVideoToPlaylist(playlistId, videoId):
         """
         Add the current video to the chosen playlist.
         """
-        playlistId = playlist.id.text
-        playlistUri = "http://gdata.youtube.com/feeds/api/playlists/%s" % playlistId.split("/")[-1]
+        playlistUri = "http://gdata.youtube.com/feeds/api/playlists/%s" % playlistId
         YouTubeDataService.ytService.AddPlaylistVideoEntryToPlaylist(playlistUri, videoId)
 
     @staticmethod
-    def removeVideoFromPlaylist(playlistEntry):
+    def removeVideoFromPlaylist(playlistId, videoId):
         """
         Removes the chosen video from the playlist.
         """
-        playlistUri = playlistEntry[:playlistEntry.rfind("/")]
-        videoId = playlistEntry.split("/")[-1]
-        YouTubeDataService.ytService.DeletePlaylistVideoEntry(playlistUri, videoId)
+        playlistUri = "http://gdata.youtube.com/feeds/api/playlists/%s" % playlistId
+        try:
+            YouTubeDataService.ytService.DeletePlaylistVideoEntry(playlistUri, videoId)
+            result = True
+        except gdata.service.Error, e:
+            result = e.args[0].get("body")
+            CutetubeLog.logException(e)
+        return result
 
     @staticmethod
     def updatePlaylistVideo(playlistId, playlistVideoId, newVideoTitle, newVideoDescription, newPosition):
@@ -138,15 +176,22 @@ class YouTubeDataService(object):
         YouTubeDataService.ytService.UpdatePlaylist(playlistId, newPlaylistTitle, newPlaylistDescription, private)
 
     @staticmethod
-    def deletePlaylist(playlistUri):
-        YouTubeDataService.ytService.DeletePlaylist(playlistUri)
+    def deletePlaylist(playlistId):
+        playlistUri = "http://gdata.youtube.com/feeds/api/users/default/playlists/%s" % playlistId
+        try:
+            YouTubeDataService.ytService.DeletePlaylist(playlistUri)
+            result = True
+        except gdata.service.Error, e:
+            result = e.args[0].get("body")
+            CutetubeLog.logException(e)
+        return result
 
     @staticmethod
-    def getVideoEntry(videoId):
+    def getVideoEntry(videoId, apiVersion = 1):
         try:
-            videoEntry = YouTubeDataService.ytService.GetYouTubeVideoEntry(videoId)
+            videoEntry = YouTubeDataService.ytService.GetYouTubeVideoEntry(video_id = videoId, api_version = apiVersion)
         except:
-            videoEntry = YouTubeDataService.ytService.GetYouTubeVideoEntry(video_id = videoId)
+            videoEntry = YouTubeDataService.ytService.GetYouTubeVideoEntry(videoId, api_version = apiVersion)
         return videoEntry
         
     @staticmethod
@@ -243,7 +288,8 @@ class YouTubeVideoFeed(QThread):
         self.videoList = []
         self.results = 0
         self.thumbcount = 0
-        self.totalResults = 0
+        self.retriesRemaining = 3
+        self.moreResults = True
         
     def resetResultCount(self):
         """
@@ -259,33 +305,31 @@ class YouTubeVideoFeed(QThread):
         """
         try:
             try:
-                self.ytVideoFeed = YouTubeDataService.ytService.GetYouTubeVideoFeed(("%s?start-index=%d" % (self.videoFeed, self.results + 1)).encode("utf-8"))
+                self.ytVideoFeed = YouTubeDataService.ytService.GetYouTubeVideoFeed(("%s?start-index=%d&v=2" % (self.videoFeed, self.results + 1)).encode("utf-8"))
             except:
-                self.ytVideoFeed = YouTubeDataService.ytService.GetYouTubeVideoFeed(("%s&start-index=%d" % (self.videoFeed, self.results + 1)).encode("utf-8"))
-            self.totalResults = int(self.ytVideoFeed.total_results.text)
+                self.ytVideoFeed = YouTubeDataService.ytService.GetYouTubeVideoFeed(("%s&start-index=%d&v=2" % (self.videoFeed, self.results + 1)).encode("utf-8"))
+            for link in self.ytVideoFeed.link:
+                self.moreResults = (link.rel == "next")
         except Exception, e:
-            CutetubeLog.logException("Unable to retrieve video feed. Trying again")
-            try:
-                try:
-                    self.ytVideoFeed = YouTubeDataService.ytService.GetYouTubeVideoFeed(("%s?start-index=%d" % (self.videoFeed, self.results + 1)).encode("utf-8"))
-                except:
-                    self.ytVideoFeed = YouTubeDataService.ytService.GetYouTubeVideoFeed(("%s&start-index=%d" % (self.videoFeed, self.results + 1)).encode("utf-8"))
-                self.totalResults = int(self.ytVideoFeed.total_results.text)
-            except Exception, e:
-                CutetubeLog.logException("Unable to retrieve video feed. Aborting: ")
+            if self.retriesRemaining > 0:
+                CutetubeLog.logException("Unable to retrieve video feed. Trying again")
+                self.retriesRemaining -= 1
+                self.getVideoFeed()
+            else:
+                CutetubeLog.logException("Unable to retrieve video feed. Aborting")
             
     def getVideoData(self):
         """
         Returns the xml for each video.
         """
         for video in self.ytVideoFeed.entry:
-            if YouTubeDataService.getVideoRestrictions(video) == None:
-                try:
+            try:
+                if video.media.player != None:
                     self.videoList.append(video)
                     self.emit(SIGNAL("dataLoaded(PyQt_PyObject)"), video)
                     self.results += 1
-                except Exception, e:
-                    CutetubeLog.logException("Unable to retrieve video entry: \'%s\': " % video.media.title.text)
+            except Exception, e:
+                CutetubeLog.logException("Unable to retrieve video entry: \'%s\': " % video.media.title.text)
                 
     def getThumbnails(self):
         """
@@ -293,7 +337,7 @@ class YouTubeVideoFeed(QThread):
         """
         for video in self.videoList[self.thumbcount:]:
             try:
-                thumbnail = YouTubeDataService.getVideoThumbnail(video.media.thumbnail[3].url)
+                thumbnail = YouTubeDataService.getVideoThumbnail(video.media.thumbnail[0].url)
                 self.emit(SIGNAL("thumbnailLoaded(PyQt_PyObject)"), (self.thumbcount, thumbnail))
                 self.thumbcount += 1
             except Exception, e:
@@ -335,7 +379,7 @@ class YouTubeQueueFeed(QThread):
         row = 0
         for video in YouTubeQueueFeed.playlist:
             try:
-                thumbnail = YouTubeDataService.getVideoThumbnail(video.media.thumbnail[3].url)
+                thumbnail = YouTubeDataService.getVideoThumbnail(video.media.thumbnail[0].url)
                 self.emit(SIGNAL("thumbnailLoaded(PyQt_PyObject)"), (row, thumbnail))
                 row += 1
             except Exception, e:
@@ -373,7 +417,7 @@ class YouTubeDownloadQueueFeed(QThread):
         for task in YouTubeVideoDownloader.taskQueue:
             try:
                 video = task.video
-                thumbnail = YouTubeDataService.getVideoThumbnail(video.media.thumbnail[3].url)
+                thumbnail = YouTubeDataService.getVideoThumbnail(video.media.thumbnail[0].url)
                 self.emit(SIGNAL("thumbnailLoaded(PyQt_PyObject)"), (row, thumbnail))
                 row += 1
             except Exception, e:
@@ -392,15 +436,24 @@ class YouTubePlaylistFeed(QThread):
 
     def __init__(self, parent):
         QThread.__init__(self, parent)
+        self.retriesRemaining = 3
 
     
     def getPlaylistFeed(self):
         """
         Retrieves and returns the user's playlist feed.
         """
-        playlistsUri = "http://gdata.youtube.com/feeds/api/users/default/playlists?max-results=50"
-        self.playlistFeed = YouTubeDataService.ytService.GetYouTubePlaylistFeed(uri = playlistsUri)
-        self.emit(SIGNAL("dataLoaded(PyQt_PyObject)"), self.playlistFeed.entry)
+        playlistsUri = "http://gdata.youtube.com/feeds/api/users/default/playlists?max-results=50&v=2"
+        try:
+            self.playlistFeed = YouTubeDataService.ytService.GetYouTubePlaylistFeed(uri = playlistsUri)
+            self.emit(SIGNAL("dataLoaded(PyQt_PyObject)"), self.playlistFeed.entry)
+        except Exception, e:
+            if self.retriesRemaining > 0:
+                CutetubeLog.logException("Unable to retrieve playlist feed. Trying again")
+                self.retriesRemaining -= 1
+                self.getPlaylistFeed()
+            else:
+                CutetubeLog.logException("Unable to retrieve playlist feed. Aborting")
     
     def run(self):
         self.getPlaylistFeed()
@@ -414,14 +467,23 @@ class YouTubeSubscriptionsFeed(QThread):
         Constructor
         """
         QThread.__init__(self, parent)
+        self.retriesRemaining = 3
 
     def getSubscriptionsFeed(self):
         """
         Retrieves the user's subscriptions feed.
         """
-        subscriptionsUri = "http://gdata.youtube.com/feeds/api/users/default/subscriptions?max-results=50"
-        self.subscriptionsFeed = YouTubeDataService.ytService.GetYouTubeSubscriptionFeed(uri = subscriptionsUri)
-        self.emit(SIGNAL("dataLoaded(PyQt_PyObject)"), self.subscriptionsFeed.entry)
+        subscriptionsUri = "http://gdata.youtube.com/feeds/api/users/default/subscriptions?max-results=50&v=2"
+        try:
+            self.subscriptionsFeed = YouTubeDataService.ytService.GetYouTubeSubscriptionFeed(uri = subscriptionsUri)
+            self.emit(SIGNAL("dataLoaded(PyQt_PyObject)"), self.subscriptionsFeed.entry)
+        except Exception, e:
+            if self.retriesRemaining > 0:
+                CutetubeLog.logException("Unable to retrieve subscriptions feed. Trying again")
+                self.retriesRemaining -= 1
+                self.getSubscriptionsFeed()
+            else:
+                CutetubeLog.logException("Unable to retrieve subscriptions feed. Aborting")
 
     def run(self):
         self.getSubscriptionsFeed()
@@ -431,21 +493,29 @@ class YouTubeCommentsFeed(QThread):
     Retrieves and returns the comments feed 
     for the video.
     """
-    def __init__(self, parent, video):
+    def __init__(self, parent, videoId):
         """
         Constructor
         """
         QThread.__init__(self, parent)
-        self.video = video
+        self.videoId = videoId
+        self.retriesRemaining = 3
 
     def getVideoComments(self):
         """
         Retrieves and returns the comments feed 
         for the video.
         """
-        videoId = self.video.comments.feed_link[0].href.split("/")[-2]
-        comments = YouTubeDataService.ytService.GetYouTubeVideoCommentFeed(video_id = videoId)
-        self.emit(SIGNAL("dataLoaded(PyQt_PyObject)"), comments.entry)
+        try:
+            comments = YouTubeDataService.ytService.GetYouTubeVideoCommentFeed(video_id = self.videoId)
+            self.emit(SIGNAL("dataLoaded(PyQt_PyObject)"), comments.entry)
+        except Exception, e:
+            if self.retriesRemaining > 0:
+                CutetubeLog.logException("Unable to retrieve comments feed. Trying again")
+                self.retriesRemaining -= 1
+                self.getVideoComments()
+            else:
+                CutetubeLog.logException("Unable to retrieve comments feed. Aborting")
 
     def run(self):
         self.getVideoComments()
